@@ -1,5 +1,5 @@
 import torch
-from ...utils.data.data_classes import patient_samples_single_tp
+from ...utils.data.data_classes import DualEntity
 
 
 class ToTensor(object):
@@ -11,5 +11,5 @@ class ToTensor(object):
             sample_dict_copy['FIELD0'] = torch.tensor(sample.patient_dict['FIELD0'].values.astype('float64')).type(torch.FloatTensor)
         if sample_dict_copy.get('FIELD1', None) is not None:
             sample_dict_copy['FIELD1'] = torch.tensor(sample.patient_dict['FIELD1'].values.astype('float64')).type(torch.FloatTensor)
-        return patient_samples_single_tp(sample_dict_copy)
+        return DualEntity(sample_dict_copy)
 
